@@ -4,7 +4,5 @@ from starlette.requests import Request
 def extract_ip_from_request(request: Request) -> str:
     forwarded_for = request.headers.get("X-Forwarded-For")
     if forwarded_for:
-        ip = forwarded_for.split(",")[0]
-    else:
-        ip = request.client.host
-    return ip
+        return forwarded_for.split(",")[0]
+    return request.client.host
